@@ -17,10 +17,10 @@ public:
     explicit BacktraceParserLldb(QObject *parent = nullptr);
 
 protected Q_SLOTS:
-    virtual void newLine(const QString &lineStr) override;
+    void newLine(const QString &lineStr) override;
 
 protected:
-    virtual BacktraceParserPrivate *constructPrivate() const override;
+    BacktraceParserPrivate *constructPrivate() const override;
 };
 
 #endif // BACKTRACEPARSERLLDB_H
